# quantitative_vale_model 

This package consists in a Simple and profitable quantitative model to user in Brazilian VALE3 (VALE S.A.) Stocks

[![PyPI Version](https://img.shields.io/pypi/v/quantitative-vale-model.svg)](https://pypi.org/project/quantitative-vale-model/)
[![Python Version](https://img.shields.io/badge/python-3.8.5-VERDE.svg)](https://www.python.org/downloads/release/python-385/)



## Install
```bash
pip install quantitative-vale-model
```
## Import
```python
import quantitative_vale_model
```

## Call the principal functions
```python
quantitative_vale_model.backtest('%Y-%m-%d')

```

```python
quantitative_vale_model.trade_action()

```